pub enum GridTemplateType {
Invalid,
Initial,
Inherit,
Unset,
Var(Box<StrRef>),
VarInShorthand(Box<StrRef>, Box<StrRef>),
None,
TrackList(Array<TrackListItem>),
// some variants omitted
}Expand description
The grid-template-rows property defines the line names and track sizing functions of the grid rows.
Variants
Invalid
Initial
Inherit
Unset
Var(Box<StrRef>)
VarInShorthand(Box<StrRef>, Box<StrRef>)
None
A keyword meaning that there is no explicit grid
TrackList(Array<TrackListItem>)